diff --git a/angular-material/angular-material-tests.ts b/angular-material/angular-material-tests.ts
index 740a72d086..e9517814a6 100644
--- a/angular-material/angular-material-tests.ts
+++ b/angular-material/angular-material-tests.ts
@@ -55,6 +55,18 @@ myApp.controller('DialogController', ($scope: ng.IScope, $mdDialog: ng.material.
$scope['confirmDialog'] = () => {
$mdDialog.show($mdDialog.confirm().htmlContent('Confirm!'));
};
+ $scope['promptDialog'] = () => {
+ $mdDialog.show($mdDialog.prompt().textContent('Prompt!'));
+ };
+ $scope['promptDialog'] = () => {
+ $mdDialog.show($mdDialog.prompt().htmlContent('Prompt!'));
+ };
+ $scope['promptDialog'] = () => {
+ $mdDialog.show($mdDialog.prompt().cancel('Prompt "Cancel" button text'));
+ };
+ $scope['promptDialog'] = () => {
+ $mdDialog.show($mdDialog.prompt().placeholder('Prompt input placeholder text'));
+ };
$scope['hideDialog'] = $mdDialog.hide.bind($mdDialog, 'hide');
$scope['cancelDialog'] = $mdDialog.cancel.bind($mdDialog, 'cancel');
});
diff --git a/angular-material/index.d.ts b/angular-material/index.d.ts
index 2e65c11773..5a4fe6d8fa 100644
--- a/angular-material/index.d.ts
+++ b/angular-material/index.d.ts
@@ -3,8 +3,6 @@
// Definitions by: Matt Traynham
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
-///
-
import * as angular from 'angular';
declare module 'angular' {
@@ -64,6 +62,11 @@ declare module 'angular' {
cancel(cancel: string): IConfirmDialog;
}
+ interface IPromptDialog extends IPresetDialog {
+ cancel(cancel: string): IPromptDialog;
+ placeholder(placeholder: string): IPromptDialog;
+ }
+
interface IDialogOptions {
templateUrl?: string;
template?: string;
@@ -94,6 +97,7 @@ declare module 'angular' {
show(dialog: IDialogOptions | IAlertDialog | IConfirmDialog): angular.IPromise;
confirm(): IConfirmDialog;
alert(): IAlertDialog;
+ prompt(): IPromptDialog;
hide(response?: any): angular.IPromise;
cancel(response?: any): void;
}
diff --git a/angular-ui-bootstrap/index.d.ts b/angular-ui-bootstrap/index.d.ts
index 8b915b3550..21e246f22f 100644
--- a/angular-ui-bootstrap/index.d.ts
+++ b/angular-ui-bootstrap/index.d.ts
@@ -379,6 +379,12 @@ declare module 'angular' {
* @default 'model-open'
*/
openedClass?: string;
+
+ /**
+ * CSS class(es) to be added to the top modal window.
+ */
+
+ windowTopClass?: string;
}
interface IModalStackService {
diff --git a/angular/angular-component-router.d.ts b/angular/angular-component-router.d.ts
index d1c2a7e373..7e1d31d063 100644
--- a/angular/angular-component-router.d.ts
+++ b/angular/angular-component-router.d.ts
@@ -427,4 +427,55 @@ declare namespace angular {
interface OnReuse {
$routerOnReuse(next?: angular.ComponentInstruction, prev?: angular.ComponentInstruction): any;
}
+
+ /**
+ * Runtime representation a type that a Component or other object is instances of.
+ *
+ * An example of a `Type` is `MyCustomComponent` class, which in JavaScript is be represented by
+ * the `MyCustomComponent` constructor function.
+ */
+ interface Type extends Function {
+ }
+
+ /**
+ * `RouteDefinition` defines a route within a {@link RouteConfig} decorator.
+ *
+ * Supported keys:
+ * - `path` or `aux` (requires exactly one of these)
+ * - `component`, `loader`, `redirectTo` (requires exactly one of these)
+ * - `name` or `as` (optional) (requires exactly one of these)
+ * - `data` (optional)
+ *
+ * See also {@link Route}, {@link AsyncRoute}, {@link AuxRoute}, and {@link Redirect}.
+ */
+ interface RouteDefinition {
+ path?: string;
+ aux?: string;
+ component?: Type | ComponentDefinition | string;
+ loader?: Function;
+ redirectTo?: any[];
+ as?: string;
+ name?: string;
+ data?: any;
+ useAsDefault?: boolean;
+ }
+
+ /**
+ * Represents either a component type (`type` is `component`) or a loader function
+ * (`type` is `loader`).
+ *
+ * See also {@link RouteDefinition}.
+ */
+ interface ComponentDefinition {
+ type: string;
+ loader?: Function;
+ component?: Type;
+ }
+
+ // Supplement IComponentOptions from angular.d.ts with router-specific
+ // fields.
+ interface IComponentOptions {
+ $canActivate?: () => boolean;
+ $routeConfig?: RouteDefinition[];
+ }
}
diff --git a/angular/index.d.ts b/angular/index.d.ts
index 33d9f5aef1..a7c04e10b1 100644
--- a/angular/index.d.ts
+++ b/angular/index.d.ts
@@ -1658,50 +1658,6 @@ declare namespace angular {
// see http://angularjs.blogspot.com.br/2015/11/angularjs-15-beta2-and-14-releases.html
// and http://toddmotto.com/exploring-the-angular-1-5-component-method/
///////////////////////////////////////////////////////////////////////////
- /**
- * Runtime representation a type that a Component or other object is instances of.
- *
- * An example of a `Type` is `MyCustomComponent` class, which in JavaScript is be represented by
- * the `MyCustomComponent` constructor function.
- */
- interface Type extends Function {
- }
-
- /**
- * `RouteDefinition` defines a route within a {@link RouteConfig} decorator.
- *
- * Supported keys:
- * - `path` or `aux` (requires exactly one of these)
- * - `component`, `loader`, `redirectTo` (requires exactly one of these)
- * - `name` or `as` (optional) (requires exactly one of these)
- * - `data` (optional)
- *
- * See also {@link Route}, {@link AsyncRoute}, {@link AuxRoute}, and {@link Redirect}.
- */
- interface RouteDefinition {
- path?: string;
- aux?: string;
- component?: Type | ComponentDefinition | string;
- loader?: Function;
- redirectTo?: any[];
- as?: string;
- name?: string;
- data?: any;
- useAsDefault?: boolean;
- }
-
- /**
- * Represents either a component type (`type` is `component`) or a loader function
- * (`type` is `loader`).
- *
- * See also {@link RouteDefinition}.
- */
- interface ComponentDefinition {
- type: string;
- loader?: Function;
- component?: Type;
- }
-
/**
* Component definition object (a simplified directive definition object)
*/
diff --git a/async/index.d.ts b/async/index.d.ts
index c3d218fabc..6ec52cf1e6 100644
--- a/async/index.d.ts
+++ b/async/index.d.ts
@@ -12,7 +12,7 @@ interface AsyncResultObjectCallback { (err: Error, results: Dictionary): v
interface AsyncFunction { (callback: (err?: Error, result?: T) => void): void; }
interface AsyncIterator { (item: T, callback: ErrorCallback): void; }
-interface AsyncForEachOfIterator { (item: T, key: number, callback: ErrorCallback): void; }
+interface AsyncForEachOfIterator { (item: T, key: number|string, callback: ErrorCallback): void; }
interface AsyncResultIterator { (item: T, callback: AsyncResultCallback): void; }
interface AsyncMemoIterator { (memo: R, item: T, callback: AsyncResultCallback): void; }
interface AsyncBooleanIterator { (item: T, callback: (err: string, truthValue: boolean) => void): void; }
diff --git a/bezier-js/bezier-js-tests.ts b/bezier-js/bezier-js-tests.ts
index 1814d67dc0..54c629d11b 100644
--- a/bezier-js/bezier-js-tests.ts
+++ b/bezier-js/bezier-js-tests.ts
@@ -31,7 +31,7 @@ function test() {
bezier.get(1);
bezier.getLUT()[0].x;
bezier.hull(0);
- bezier.inflections().values;
+ bezier.extrema();
bezier.intersects(bezier);
bezier.length();
bezier.lineIntersects(line);
@@ -48,7 +48,8 @@ function test() {
bezier.scale(4);
bezier.selfintersects();
bezier.simple();
- bezier.split(0, 1);
+ bezier.split(0, 1).clockwise;
+ bezier.split(0.5).left;
bezier.toSVG();
bezier.update();
diff --git a/bezier-js/bezier-js.d.ts b/bezier-js/bezier-js.d.ts
index 7d54a19d95..35e5cc19f1 100644
--- a/bezier-js/bezier-js.d.ts
+++ b/bezier-js/bezier-js.d.ts
@@ -117,7 +117,8 @@ declare module BezierJs {
private __normal3(t);
private __normal(t);
hull(t: number): Point[];
- split(t1: number, t2?: number): Bezier | Split;
+ split(t1: number): Split;
+ split(t1: number, t2: number): Bezier;
extrema(): Inflection;
bbox(): BBox;
overlaps(curve: Bezier): boolean;
diff --git a/bingmaps/index.d.ts b/bingmaps/index.d.ts
index c558c7a64b..95e39a043e 100644
--- a/bingmaps/index.d.ts
+++ b/bingmaps/index.d.ts
@@ -301,7 +301,7 @@ declare namespace Microsoft.Maps {
getShowPointer(): boolean;
getTitle(): string;
getTitleAction(): any;
- getTitleClickHandler(): () => void;
+ getTitleClickHandler(): (mouseEvent?: MouseEvent) => void;
getVisible(): boolean;
getWidth(): number;
getZIndex(): number;
@@ -329,8 +329,8 @@ declare namespace Microsoft.Maps {
showPointer?: boolean;
pushpin?: Pushpin;
title?: string;
- titleAction?: { label?: string; eventHandler: () => void; };
- titleClickHandler?: () => void;
+ titleAction?: { label?: string; eventHandler: (mouseEvent?: MouseEvent) => void; };
+ titleClickHandler?: (mouseEvent?: MouseEvent) => void;
typeName?: InfoboxType;
visible?: boolean;
width?: number;
diff --git a/core-js/index.d.ts b/core-js/index.d.ts
index 2c1fa4bd99..e9be316364 100644
--- a/core-js/index.d.ts
+++ b/core-js/index.d.ts
@@ -790,8 +790,17 @@ interface PromiseConstructor {
* @param values An array of Promises.
* @returns A new Promise.
*/
- all(values: Iterable>): Promise;
-
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike , T5 | PromiseLike, T6 | PromiseLike, T7 | PromiseLike, T8 | PromiseLike, T9 | PromiseLike, T10 | PromiseLike]): Promise<[T1, T2, T3, T4, T5, T6, T7, T8, T9, T10]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike , T5 | PromiseLike, T6 | PromiseLike, T7 | PromiseLike, T8 | PromiseLike, T9 | PromiseLike]): Promise<[T1, T2, T3, T4, T5, T6, T7, T8, T9]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike , T5 | PromiseLike, T6 | PromiseLike, T7 | PromiseLike, T8 | PromiseLike]): Promise<[T1, T2, T3, T4, T5, T6, T7, T8]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike , T5 | PromiseLike, T6 | PromiseLike, T7 | PromiseLike]): Promise<[T1, T2, T3, T4, T5, T6, T7]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike , T5 | PromiseLike, T6 | PromiseLike]): Promise<[T1, T2, T3, T4, T5, T6]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike , T5 | PromiseLike]): Promise<[T1, T2, T3, T4, T5]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike, T4 | PromiseLike ]): Promise<[T1, T2, T3, T4]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike, T3 | PromiseLike]): Promise<[T1, T2, T3]>;
+ all(values: [T1 | PromiseLike, T2 | PromiseLike]): Promise<[T1, T2]>;
+ all(values: Iterable>): Promise;
+
/**
* Creates a Promise that is resolved or rejected when any of the provided Promises are resolved
* or rejected.
diff --git a/dagre-d3/dagre-d3-tests.ts b/dagre-d3/dagre-d3-tests.ts
index 030c4e4f4e..0b58a0f3c9 100644
--- a/dagre-d3/dagre-d3-tests.ts
+++ b/dagre-d3/dagre-d3-tests.ts
@@ -13,6 +13,6 @@ namespace DagreD3Tests {
const render = new dagreD3.render();
const svg = d3.select("svg");
- render.arrows()["arrowType"] = (parent: JQuery, id: string, edge: Dagre.Edge, type: string) => {};
+ render.arrows()["arrowType"] = (parent: d3.Selection, id: string, edge: Dagre.Edge, type: string) => {};
render(svg, graph);
}
diff --git a/dagre-d3/index.d.ts b/dagre-d3/index.d.ts
index c4738120c3..8513b23538 100644
--- a/dagre-d3/index.d.ts
+++ b/dagre-d3/index.d.ts
@@ -25,7 +25,7 @@ declare namespace Dagre {
interface Render {
// see http://cpettitt.github.io/project/dagre-d3/latest/demo/user-defined.html for example usage
- arrows (): { [arrowStyleName: string]: (parent: JQuery, id: string, edge: Dagre.Edge, type: string) => void };
+ arrows (): { [arrowStyleName: string]: (parent: d3.Selection, id: string, edge: Dagre.Edge, type: string) => void };
new (): Render;
(selection: d3.Selection, g: Dagre.Graph): void;
}
diff --git a/es6-shim/index.d.ts b/es6-shim/index.d.ts
index 1c3df0ed7f..b2cad2f4ce 100644
--- a/es6-shim/index.d.ts
+++ b/es6-shim/index.d.ts
@@ -582,6 +582,7 @@ interface Set {
entries(): IterableIteratorShim<[T, T]>;
keys(): IterableIteratorShim;
values(): IterableIteratorShim;
+ '_es6-shim iterator_'(): IterableIteratorShim;
}
interface SetConstructor {
diff --git a/express-domain-middleware/express-domain-middleware-tests.ts b/express-domain-middleware/express-domain-middleware-tests.ts
new file mode 100644
index 0000000000..446b732353
--- /dev/null
+++ b/express-domain-middleware/express-domain-middleware-tests.ts
@@ -0,0 +1,2 @@
+///
+import fn = require('express-domain-middleware');
diff --git a/express-domain-middleware/express-domain-middleware.d.ts b/express-domain-middleware/express-domain-middleware.d.ts
new file mode 100644
index 0000000000..1710d548e0
--- /dev/null
+++ b/express-domain-middleware/express-domain-middleware.d.ts
@@ -0,0 +1,12 @@
+// Type definitions for express-domain-middleware
+// Project: https://www.npmjs.com/package/express-domain-middleware
+// Definitions by: Hookclaw
+// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
+
+///
+
+declare module "express-domain-middleware" {
+ import express = require('express');
+ function e(req: express.Request, res: express.Response, next: express.NextFunction): any;
+ export = e;
+}
diff --git a/fontfaceobserver/fontfaceobserver-tests.ts b/fontfaceobserver/fontfaceobserver-tests.ts
new file mode 100644
index 0000000000..1ea9a7a222
--- /dev/null
+++ b/fontfaceobserver/fontfaceobserver-tests.ts
@@ -0,0 +1,46 @@
+///
+
+function test1() {
+ var font = new FontFaceObserver('My Family', {
+ weight: 400
+ });
+
+ font.load().then(function () {
+ console.log('Font is available');
+ }, function () {
+ console.log('Font is not available');
+ });
+}
+
+function test2() {
+ var font = new FontFaceObserver('My Family');
+
+ font.load('中国').then(function () {
+ console.log('Font is available');
+ }, function () {
+ console.log('Font is not available');
+ });
+}
+
+function test3() {
+ var font = new FontFaceObserver('My Family');
+
+ font.load(null, 5000).then(function () {
+ console.log('Font is available');
+ }, function () {
+ console.log('Font is not available after waiting 5 seconds');
+ });
+}
+
+function test4() {
+ var fontA = new FontFaceObserver('Family A');
+ var fontB = new FontFaceObserver('Family B');
+
+ fontA.load().then(function () {
+ console.log('Family A is available');
+ });
+
+ fontB.load().then(function () {
+ console.log('Family B is available');
+ });
+}
diff --git a/fontfaceobserver/fontfaceobserver-tests.ts.tscparams b/fontfaceobserver/fontfaceobserver-tests.ts.tscparams
new file mode 100644
index 0000000000..14fce22a5c
--- /dev/null
+++ b/fontfaceobserver/fontfaceobserver-tests.ts.tscparams
@@ -0,0 +1 @@
+--target ES6
diff --git a/fontfaceobserver/fontfaceobserver.d.ts b/fontfaceobserver/fontfaceobserver.d.ts
new file mode 100644
index 0000000000..8f461dbd4f
--- /dev/null
+++ b/fontfaceobserver/fontfaceobserver.d.ts
@@ -0,0 +1,33 @@
+// Type definitions for fontfaceobserver
+// Project: https://github.com/bramstein/fontfaceobserver
+// Definitions by: Rand Scullard
+// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
+
+
+declare namespace FontFaceObserver {
+ interface FontVariant {
+ weight?: number | string;
+ style?: string;
+ stretch?: string;
+ }
+}
+
+declare class FontFaceObserver {
+ /**
+ * Creates a new FontFaceObserver.
+ * @param fontFamilyName Name of the font family to observe.
+ * @param variant Description of the font variant to observe. If a property is not present it will default to normal.
+ */
+ constructor(fontFamilyName: string, variant?: FontFaceObserver.FontVariant);
+
+ /**
+ * Starts observing the loading of the specified font. Immediately returns a new Promise that resolves when the font is available and rejected when the font is not available.
+ * @param testString If your font doesn't contain latin characters you can pass a custom test string.
+ * @param timeout The default timeout for giving up on font loading is 3 seconds. You can increase or decrease this by passing a number of milliseconds.
+ */
+ load(testString?: string, timeout?: number): Promise;
+}
+
+declare module "fontfaceobserver" {
+ export = FontFaceObserver;
+}
diff --git a/fullpage.js/fullpage.js-tests.ts b/fullpage.js/fullpage.js-tests.ts
new file mode 100644
index 0000000000..31e66fdd60
--- /dev/null
+++ b/fullpage.js/fullpage.js-tests.ts
@@ -0,0 +1,64 @@
+///
+
+function test_public_methods() {
+ $(() => {
+ $('#fullpage').fullpage({
+ // Navigation
+ menu: '#menu',
+ lockAnchors: false,
+ anchors:['firstPage', 'secondPage'],
+ navigation: false,
+ navigationPosition: 'right',
+ navigationTooltips: ['firstSlide', 'secondSlide'],
+ showActiveTooltip: false,
+ slidesNavigation: true,
+ slidesNavPosition: 'bottom',
+
+ // Scrolling
+ css3: true,
+ scrollingSpeed: 700,
+ autoScrolling: true,
+ fitToSection: true,
+ fitToSectionDelay: 1000,
+ scrollBar: false,
+ easing: 'easeInOutCubic',
+ easingcss3: 'ease',
+ loopBottom: false,
+ loopTop: false,
+ loopHorizontal: true,
+ continuousVertical: false,
+ normalScrollElements: '#element1, .element2',
+ scrollOverflow: false,
+ scrollOverflowOptions: null,
+ touchSensitivity: 15,
+ normalScrollElementTouchThreshold: 5,
+
+ // Accessibility
+ keyboardScrolling: true,
+ animateAnchor: true,
+ recordHistory: true,
+
+ // Design
+ controlArrows: true,
+ verticalCentered: true,
+ sectionsColor : ['#ccc', '#fff'],
+ paddingTop: '3em',
+ paddingBottom: '10px',
+ fixedElements: '#header, .footer',
+ responsiveWidth: 0,
+ responsiveHeight: 0,
+
+ // Custom selectors
+ sectionSelector: '.section',
+ slideSelector: '.slide',
+
+ // Events
+ onLeave: (index, nextIndex, direction) => {},
+ afterLoad: (anchorLink, index) => {},
+ afterRender: () => {},
+ afterResize: () => {},
+ afterSlideLoad: (anchorLink, index, slideAnchor, slideIndex) => {},
+ onSlideLeave: (anchorLink, index, slideIndex, direction, nextSlideIndex) => {}
+ });
+ });
+}
diff --git a/fullpage.js/fullpage.js.d.ts b/fullpage.js/fullpage.js.d.ts
new file mode 100644
index 0000000000..b2bedc62d9
--- /dev/null
+++ b/fullpage.js/fullpage.js.d.ts
@@ -0,0 +1,267 @@
+// Type definitions for fullpage.js v2.8.0
+// Project: http://alvarotrigo.com/fullPage/
+// Definitions by: Andrew Roberts
+// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
+
+///
+
+interface FullPageJsOptions {
+ /**
+ * (default false) A selector can be used to specify the menu to link with the sections. This way the scrolling of the sections will activate the corresponding element in the menu using the class active. This won't generate a menu but will just add the active class to the element in the given menu with the corresponding anchor links. In order to link the elements of the menu with the sections, an HTML 5 data-tag (data-menuanchor) will be needed to use with the same anchor links as used within the sections.
+ */
+ menu?: string;
+
+ /**
+ * (default false). Determines whether anchors in the URL will have any effect at all in the plugin. You can still using anchors internally for your own functions and callbacks, but they won't have any effect in the scrolling of the site. Useful if you want to combine fullPage.js with other plugins using anchor in the URL.
+ */
+ lockAnchors?: boolean;
+
+ /**
+ * (default []) Defines the anchor links (#example) to be shown on the URL for each section. Anchors value should be unique. The position of the anchors in the array will define to which sections the anchor is applied. (second position for second section and so on). Using anchors forward and backward navigation will also be possible through the browser. This option also allows users to bookmark a specific section or slide. Be careful! anchors can not have the same value as any ID element on the site (or NAME element for IE). Now anchors can be defined directly in the HTML structure by using the attribute data-anchor as explained here.
+ */
+ anchors?: string[];
+
+ /**
+ * (default false) If set to true, it will show a navigation bar made up of small circles.
+ */
+ navigation?: boolean;
+
+ /**
+ * (default none) It can be set to left or right and defines which position the navigation bar will be shown (if using one).
+ */
+ navigationPosition?: string;
+
+ /**
+ * (default []) Defines the tooltips to show for the navigation circles in case they are being used. Example: navigationTooltips: ['firstSlide', 'secondSlide'].
+ */
+ navigationTooltips?: string[];
+
+ /**
+ * (default false) Shows a persistent tooltip for the actively viewed section in the vertical navigation.
+ */
+ showActiveTooltip?: boolean;
+
+ /**
+ * (default false) If set to true it will show a navigation bar made up of small circles for each landscape slider on the site.
+ */
+ slidesNavigation?: boolean;
+
+ /**
+ * (default bottom) Defines the position for the landscape navigation bar for sliders. Admits top and bottom as values. You may want to modify the CSS styles to determine the distance from the top or bottom as well as any other style such as color.
+ */
+ slidesNavPosition?: string;
+
+ // Scrolling
+
+ /**
+ * (default true). Defines whether to use JavaScript or CSS3 transforms to scroll within sections and slides. Useful to speed up the movement in tablet and mobile devices with browsers supporting CSS3. If this option is set to true and the browser doesn't support CSS3, a jQuery fallback will be used instead.
+ */
+ css3?: boolean;
+
+ /**
+ * (default 700) Speed in milliseconds for the scrolling transitions.
+ */
+ scrollingSpeed?: number;
+
+ /**
+ * (default true) Defines whether to use the "automatic" scrolling or the "normal" one. It also has affects the way the sections fit in the browser/device window in tablets and mobile phones.
+ */
+ autoScrolling?: boolean;
+
+ /**
+ * (default true). Determines whether or not to fit sections to the viewport or not. When set to true the current active section will always fill the whole viewport. Otherwise the user will be free to stop in the middle of a section (when )
+ */
+ fitToSection?: boolean;
+
+ /**
+ * (default 1000). If fitToSection is set to true, this delays the fitting by the configured milliseconds.
+ */
+ fitToSectionDelay?: number;
+
+ /**
+ * (default false). Determines whether to use scrollbar for the site or not. In case of using scroll bar, the autoScrolling functionality will still working as expected. The user will also be free to scroll the site with the scroll bar and fullPage.js will fit the section in the screen when scrolling finishes.
+ */
+ scrollBar?: boolean;
+
+ /**
+ * (default easeInOutCubic) Defines the transition effect to use for the vertical and horizontal scrolling. It requires the file vendors/jquery.easings.min.js or jQuery UI for using some of its transitions. Other libraries could be used instead.
+ */
+ easing?: string;
+
+ /**
+ * (default ease) Defines the transition effect to use in case of using css3:true. You can use the pre-defined ones (such as linear, ease-out...) or create your own ones using the cubic-bezier function. You might want to use Matthew Lein CSS Easing Animation Tool for it.
+ */
+ easingcss3?: string;
+
+ /**
+ * (default false) Defines whether scrolling down in the last section should scroll to the first one or not.
+ */
+ loopBottom?: boolean;
+
+ /**
+ * (default false) Defines whether scrolling up in the first section should scroll to the last one or not.
+ */
+ loopTop?: boolean;
+
+ /**
+ * (default true) Defines whether horizontal sliders will loop after reaching the last or previous slide or not.
+ */
+ loopHorizontal?: boolean;
+
+ /**
+ * (default false) Defines whether scrolling down in the last section should scroll down to the first one or not, and if scrolling up in the first section should scroll up to the last one or not. Not compatible with loopTop or loopBottom.
+ */
+ continuousVertical?: boolean;
+
+ /**
+ * (default null) If you want to avoid the auto scroll when scrolling over some elements, this is the option you need to use. (useful for maps, scrolling divs etc.) It requires a string with the jQuery selectors for those elements. (For example: normalScrollElements: '#element1, .element2')
+ */
+ normalScrollElements?: string;
+
+ /**
+ * (default false) defines whether or not to create a scroll for the section/slide in case its content is bigger than the height of it. When set to true, your content will be wrapped by the plugin. Consider using delegation or load your other scripts in the afterRender callback. In case of setting it to true, it requires the vendor library scrolloverflow.min.js and it should be loaded before the fullPage.js plugin.
+ */
+ scrollOverflow?: boolean;
+
+ /**
+ * when using scrollOverflow:true fullpage.js will make use of a forked and modified version of iScroll.js libary. You can customize the scrolling behaviour by providing fullpage.js with the iScroll.js options you want to use. Check its documentation for more info.
+ */
+ scrollOverflowOptions?: any;
+
+ /**
+ * (default 5) Defines a percentage of the browsers window width/height, and how far a swipe must measure for navigating to the next section / slide
+ */
+ touchSensitivity?: number;
+
+ /**
+ * (default 5) Defines the threshold for the number of hops up the html node tree Fullpage will test to see if normalScrollElements is a match to allow scrolling functionality on divs on a touch device. (For example: normalScrollElementTouchThreshold: 3)
+ */
+ normalScrollElementTouchThreshold?: number;
+
+ // Accessibility
+
+ /**
+ * (default true) Defines if the content can be navigated using the keyboard
+ */
+ keyboardScrolling?: boolean;
+
+ /**
+ * (default true) Defines whether the load of the site when given an anchor (#) will scroll with animation to its destination or will directly load on the given section.
+ */
+ animateAnchor?: boolean;
+
+ /**
+ * (default true) Defines whether to push the state of the site to the browser's history. When set to true each section/slide of the site will act as a new page and the back and forward buttons of the browser will scroll the sections/slides to reach the previous or next state of the site. When set to false, the URL will keep changing but will have no effect ont he browser's history. This option is automatically turned off when using autoScrolling:false.
+ */
+ recordHistory?: boolean;
+
+ // Design
+ /**
+ * (default: true) Determines whether to use control arrows for the slides to move right or left.
+ */
+ controlArrows?: boolean;
+
+ /**
+ * (default true) Vertically centering of the content within sections. When set to true, your content will be wrapped by the plugin. Consider using delegation or load your other scripts in the afterRender callback.
+ */
+ verticalCentered?: boolean;
+
+
+ resize ?: boolean;
+
+ /**
+ * (default none) Define the CSS background-color property for each section
+ */
+ sectionsColor ?: string[];
+
+ /**
+ * (default 0) Defines the top padding for each section with a numerical value and its measure (paddingTop: '10px', paddingTop: '10em'...) Useful in case of using a fixed header.
+ */
+ paddingTop?: string;
+
+ /**
+ * (default 0) Defines the bottom padding for each section with a numerical value and its measure (paddingBottom: '10px', paddingBottom: '10em'...). Useful in case of using a fixed footer.
+ */
+ paddingBottom?: string;
+
+ /**
+ * (default null) Defines which elements will be taken off the scrolling structure of the plugin which is necessary when using the css3 option to keep them fixed. It requires a string with the jQuery selectors for those elements. (For example: fixedElements: '#element1, .element2')
+ */
+ fixedElements?: string;
+
+ /**
+ * (default 0) A normal scroll (autoScrolling:false) will be used under the defined width in pixels. A class fp-responsive is added to the body tag in case the user wants to use it for his own responsive CSS. For example, if set to 900, whenever the browser's width is less than 900 the plugin will scroll like a normal site.
+ */
+ responsiveWidth?: number;
+
+ /**
+ * (default 0) A normal scroll (autoScrolling:false) will be used under the defined height in pixels. A class fp-responsive is added to the body tag in case the user wants to use it for his own responsive CSS. For example, if set to 900, whenever the browser's height is less than 900 the plugin will scroll like a normal site.
+ */
+ responsiveHeight?: number;
+
+ // Custom selectors
+
+ /**
+ * (default .section) Defines the jQuery selector used for the plugin sections. It might need to be changed sometimes to avoid problem with other plugins using the same selectors as fullpage.js.
+ */
+ sectionSelector?: string;
+
+ /**
+ * (default .slide) Defines the jQuery selector used for the plugin slides. It might need to be changed sometimes to avoid problem with other plugins using the same selectors as fullpage.js.
+ */
+ slideSelector?: string;
+
+ // Events
+ /**
+ * This callback is fired once the user leaves a section, in the transition to the new section. Returning false will cancel the move before it takes place.
+ * @param index index of the leaving section. Starting from 1.
+ * @param nextIndex index of the destination section. Starting from 1.
+ * @param direction it will take the values up or down depending on the scrolling direction.
+ */
+ onLeave?: (index: number, nextIndex: number, direction: string) => void;
+
+ /**
+ * Callback fired once the sections have been loaded, after the scrolling has ended.
+ * @param anchorLink anchorLink corresponding to the section.
+ * @param index index of the section. Starting from 1.
+ */
+ afterLoad?: (anchorLink: string, index: number) => void;
+
+ /**
+ * This callback is fired just after the structure of the page is generated. This is the callback you want to use to initialize other plugins or fire any code which requires the document to be ready (as this plugin modifies the DOM to create the resulting structure).
+ */
+ afterRender?: () => void;
+
+ /**
+ * This callback is fired after resizing the browser's window. Just after the sections are resized.
+ */
+ afterResize?: () => void;
+
+ /**
+ * Callback fired once the slide of a section have been loaded, after the scrolling has ended.
+ *
+ * In case of not having anchorLinks defined for the slide or slides the slideIndex parameter would be the only one to use.
+ *
+ * Parameters:
+ *
+ * @param anchorLink anchorLink corresponding to the section.
+ * @param index index of the section. Starting from 1.
+ * @param slideAnchor anchor corresponding to the slide (in case there is)
+ * @param slideIndex index of the slide. Starting from 1. (the default slide doesn't count as slide, but as a section)
+ */
+ afterSlideLoad?: (anchorLink: string, index: number, slideAnchor: string, slideIndex: number) => void;
+
+ /**
+ * This callback is fired once the user leaves an slide to go to another, in the transition to the new slide. Returning false will cancel the move before it takes place.
+ * @param anchorLink: anchorLink corresponding to the section.
+ * @param index index of the section. Starting from 1.
+ * @param slideIndex index of the slide. Starting from 0.
+ * @param direction takes the values right or left depending on the scrolling direction.
+ * @param nextSlideIndex index of the destination slide. Starting from 0.
+ */
+ onSlideLeave?: (anchorLink: string, index: number, slideIndex: number, direction: string, nextSlideIndex: number) => void;
+}
+
+interface JQuery {
+ fullpage(options?: FullPageJsOptions): JQuery;
+}
diff --git a/gapi.auth2/index.d.ts b/gapi.auth2/index.d.ts
index 0c4206c5e0..3613febb09 100644
--- a/gapi.auth2/index.d.ts
+++ b/gapi.auth2/index.d.ts
@@ -64,7 +64,7 @@ declare namespace gapi.auth2 {
fetch_basic_profile?: boolean;
prompt?: boolean;
scope?: string;
- }, onsuccess: () => any, onfailure: (reason: string) => any): any;
+ }, onsuccess: (googleUser: GoogleUser) => any, onfailure: (reason: string) => any): any;
}
export interface IsSignedIn{
diff --git a/gridstack/gridstack-tests.ts b/gridstack/gridstack-tests.ts
index 2c9736b728..7ad4877f5b 100644
--- a/gridstack/gridstack-tests.ts
+++ b/gridstack/gridstack-tests.ts
@@ -12,9 +12,9 @@ var options = {
};
var gridstack:GridStack = $(document).gridstack(options);
-gridstack.add_widget("test", 1, 2, 3, 4, true);
-gridstack.batch_update();
-gridstack.cell_height();;
-gridstack.cell_height(2);
-gridstack.cell_width();
-gridstack.get_cell_from_pixel({ left:20, top: 20 });
+gridstack.addWidget("test", 1, 2, 3, 4, true);
+gridstack.batchUpdate();
+gridstack.cellHeight();;
+gridstack.cellHeight(2);
+gridstack.cellWidth();
+gridstack.getCellFromPixel({ left:20, top: 20 });
diff --git a/hapi/index.d.ts b/hapi/index.d.ts
index 9c622304b3..33c6d63f1e 100644
--- a/hapi/index.d.ts
+++ b/hapi/index.d.ts
@@ -874,7 +874,7 @@ export interface IRouteConfiguration {
/** - an optional domain string or an array of domain strings for limiting the route to only requests with a matching host header field.Matching is done against the hostname part of the header only (excluding the port).Defaults to all hosts.*/
vhost?: string;
/** - (required) the function called to generate the response after successful authentication and validation.The handler function is described in Route handler.If set to a string, the value is parsed the same way a prerequisite server method string shortcut is processed.Alternatively, handler can be assigned an object with a single key using the name of a registered handler type and value with the options passed to the registered handler.*/
- handler: ISessionHandler | string | IRouteHandlerConfig;
+ handler?: ISessionHandler | string | IRouteHandlerConfig;
/** - additional route options.*/
config?: IRouteAdditionalConfigurationOptions;
}
diff --git a/immutable/immutable-tests.ts b/immutable/immutable-tests.ts
new file mode 100644
index 0000000000..17240ebe9c
--- /dev/null
+++ b/immutable/immutable-tests.ts
@@ -0,0 +1,329 @@
+///
+
+import immutable = require('immutable')
+
+// List tests
+
+let list: immutable.List = immutable.List([0, 1, 2, 3, 4, 5]);
+let list1: immutable.List = immutable.List(list);
+
+list = immutable.List.of(0, 1, 2, 3, 4);
+let bool: boolean = immutable.List.isList(list);
+
+list = list.set(0, 1);
+list = list.delete(0);
+list = list.remove(0);
+list = list.insert(0, 1);
+list = list.clear();
+list = list.push(0, 1, 2, 3, 4, 5);
+list = list.pop();
+list = list.unshift(1, 2, 3);
+list = list.shift();
+list = list.update((value: immutable.List) => value);
+list = list.update(1, (value: number) => value);
+list = list.update(1, 1, (value: number) => value);
+list = list.merge(list1, list);
+list = list.merge([0, 1, 2], [3, 4, 5]);
+list = list.mergeWith((prev: number, next: number, key: number) => prev, list, list1);
+list = list.mergeWith((prev: number, next: number, key: number) => prev, [0, 1, 2], [3, 4, 5]);
+list = list.mergeDeep(list1, list);
+list = list.mergeDeep([0, 1, 2], [3, 4, 5]);
+list = list.mergeDeepWith((prev: number, next: number, key: number) => prev, list, list1);
+list = list.mergeDeepWith((prev: number, next: number, key: number) => prev, [0, 1, 2], [3, 4, 5]);
+list = list.setSize(5);
+list = list.setIn([0, 1, 2], 5);
+list = list.deleteIn([0, 1, 2]);
+list = list.removeIn([0, 1, 2]);
+list = list.updateIn([0, 1, 2], value => value);
+list = list.updateIn([0, 1, 2], 1, value => value);
+list = list.mergeIn([0, 1, 2], list, list1);
+list = list.mergeIn([0, 1, 2], [0, 1, 2], [3, 4, 5]);
+list = list.mergeDeepIn([0, 1, 2], list, list1);
+list = list.mergeDeepIn([0, 1, 2], [0, 1, 2], [3, 4, 5]);
+list = list.withMutations((mutable: immutable.List) => mutable);
+list = list.asMutable();
+list = list.asImmutable();
+
+// Collection.Indexed
+let indexedSeq: immutable.Seq.Indexed = list.toSeq();
+
+// Iterable tests
+let value: number = list.get(0);
+value = list.get(0, 1);
+list = list.interpose(0);
+list = list.interleave(list, list1);
+list = list.splice(0, 2, 4, 5, 6);
+list = list.zip(list1);
+let indexedIterable: immutable.Iterable.Indexed = list.zipWith(
+ (value: number, other: number) => value + other,
+ list1
+);
+let indexedIterable1: immutable.Iterable.Indexed = list.zipWith(
+ (value: number, other: number, third: number) => value + other + third,
+ list1,
+ indexedIterable
+);
+indexedIterable = list.zipWith(
+ (value: number, other: number, third: number) => value + other + third,
+ list1,
+ indexedIterable1
+);
+value = list.indexOf(1);
+value = list.lastIndexOf(1);
+value = list.findIndex((value: number, index: number, iter: immutable.List) => true);
+value = list.findLastIndex((value: number, index: number, iter: immutable.List) => true);
+value = list.size;
+
+bool = list.equals(list1);
+value = list.hashCode();
+bool = list.has(1);
+bool = list.includes(1);
+bool = list.contains(1);
+value = list.first();
+value = list.last();
+let toArr: number[] = list.toArray();
+let toMap: immutable.Map = list.toMap();
+let toOrderedMap: immutable.OrderedMap = list.toOrderedMap();
+let toSet: immutable.Set = list.toSet();
+let toOrderedSet: immutable.OrderedSet = list.toOrderedSet();
+list = list.toList();
+let toStack: immutable.Stack = list.toStack();
+let toKeyedSeq: immutable.Seq.Keyed = list.toKeyedSeq();
+indexedSeq = list.toIndexedSeq();
+let toSetSeq: immutable.Seq.Set = list.toSetSeq();
+
+let iter: immutable.Iterator = list.keys();
+iter = list.values();
+let iter1: immutable.Iterator<[number, number]> = list.entries();
+
+indexedSeq = list.keySeq();
+indexedSeq = list.valueSeq();
+let indexedSeq1: immutable.Seq.Indexed<[number, number]> = list.entrySeq();
+
+let iter2: immutable.Iterable = list.map(
+ (value: number, key: number, iter: immutable.List) => "foo"
+)
+
+list = list.filterNot((value: number, key: number, iter: immutable.List) => true);
+list = list.reverse();
+list = list.sort((valA: number, valB: number) => 0);
+list = list.sortBy(
+ (value: number, key: number, iter: immutable.List) => "foo",
+ (valueA: string, valueB: string) => 0
+);
+
+let keyedSeq2: immutable.Seq.Keyed> = list.groupBy(
+ (value: number, key: number, iter: immutable.List) => ""
+);
+
+value = list.forEach((value: number, key: number, iter: immutable.List) => true);
+list = list.slice(0, 1);
+list = list.rest();
+list = list.butLast();
+list = list.skip(0);
+list = list.skipLast(0);
+list = list.skipWhile(
+ (value: number, key: number, iter: immutable.List) => true
+);
+list = list.take(2);
+list = list.takeLast(2);
+list = list.takeWhile(
+ (value: number, key: number, iter: immutable.List) => true
+);
+list = list.takeUntil(
+ (value: number, key: number, iter: immutable.List) => true
+);
+list = list.concat(list1, 2, 3);
+list = list.flatten(1);
+list = list.flatten(true);
+let str: string = list.reduce(
+ (red: string, value: number, key: number, iter: immutable.List) => red + "bar",
+ "foo"
+);
+str = list.reduceRight(
+ (red: string, value: number, key: number, iter: immutable.List) => red + "bar",
+ "foo"
+);
+bool = list.every(
+ (value: number, key: number, iter: immutable.List) => true
+);
+bool = list.some(
+ (value: number, key: number, iter: immutable.List) => true
+);
+str = list.join(",");
+bool = list.isEmpty();
+value = list.count();
+value = list.count(
+ (value: number, key: number, iter: immutable.List) => true
+);
+let keyedSeq3: immutable.Seq.Keyed = list.countBy(
+ (value: number, key: number, iter: immutable.List) => "foo"
+);
+value = list.find(
+ (value: number, key: number, iter: immutable.List) => true,
+ null,
+ 0
+);
+value = list.findLast(
+ (value: number, key: number, iter: immutable.List) => true,
+ null,
+ 0
+);
+let tuple: [number, number] = list.findEntry(
+ (value: number, key: number, iter: immutable.List) => true,
+ null,
+ 0
+);
+tuple = list.findLastEntry(
+ (value: number, key: number, iter: immutable.List) => true,
+ null,
+ 0
+);
+value = list.findKey(
+ (value: number, key: number, iter: immutable.List) => true,
+ null
+);
+value = list.findLastKey(
+ (value: number, key: number, iter: immutable.List) => true,
+ null
+);
+value = list.keyOf(0);
+value = list.lastKeyOf(0);
+value = list.max((valA: number, valB: number) => 0);
+value = list.maxBy(
+ (value: number, key: number, iter: immutable.List) => "foo",
+ (valueA: string, valueB: string) => 0
+);
+value = list.min((valA: number, valB: number) => 0);
+value = list.minBy(
+ (value: number, key: number, iter: immutable.List) => "foo",
+ (valueA: string, valueB: string) => 0
+);
+bool = list.isSubset(list1);
+bool = list.isSubset([0, 1, 2]);
+bool = list.isSuperset(list1);
+bool = list.isSuperset([0, 1, 2]);
+
+
+// Map tests
+
+let map: immutable.Map = immutable.Map();
+map = immutable.Map([["foo", 1], ["bar", 2]]);
+let map1: immutable.Map = immutable.Map(map);
+map = map.set("baz", 3);
+map.delete("foo");
+map.remove("foo");
+map = map.clear();
+map = map.update((value: immutable.Map) => value);
+map = map.update("foo", (value: number) => value);
+map = map.update("bar", 1, (value: number) => value);
+map = map.merge(map1, map);
+map = map.merge({ "foo": 0, "bar": 1}, {"baz": 2});
+map = map.mergeWith((prev: number, next: number, key: string) => prev, map, map1);
+map = map.mergeWith((prev: number, next: number, key: string) => prev,{ "foo": 0, "bar": 1}, {"baz": 2});
+map = map.mergeDeep(map1, map);
+map = map.mergeDeep({ "foo": 0, "bar": 1}, {"baz": 2});
+map = map.mergeDeepWith((prev: number, next: number, key: string) => prev, map, map1);
+map = map.mergeDeepWith((prev: number, next: number, key: string) => prev, { "foo": 0, "bar": 1}, {"baz": 2});
+map = map.setIn([0, 1, 2], 5);
+map = map.deleteIn([0, 1, 2]);
+map = map.removeIn([0, 1, 2]);
+map = map.updateIn([0, 1, 2], value => value);
+map = map.updateIn([0, 1, 2], 1, value => value);
+map = map.mergeIn([0, 1, 2], map, map1);
+map = map.mergeIn([0, 1, 2], { "foo": 0, "bar": 1}, {"baz": 2});
+map = map.mergeDeepIn([0, 1, 2], map, map1);
+map = map.mergeDeepIn([0, 1, 2], { "foo": 0, "bar": 1}, {"baz": 2});
+map = map.withMutations((mutable: immutable.Map) => mutable);
+map = map.asMutable();
+map = map.asImmutable();
+
+bool = immutable.Map.isMap(map);
+map = immutable.Map.of("foo", 0, "bar", 1);
+
+// OrderedMap tests
+bool = immutable.OrderedMap.isOrderedMap(toOrderedMap);
+toOrderedMap = immutable.OrderedMap(toOrderedMap);
+
+// Set tests
+let set: immutable.Set = immutable.Set.of(0, 1, 2, 3);
+bool = immutable.Set.isSet(set);
+set = immutable.Set.fromKeys(toMap);
+let set1: immutable.Set = immutable.Set.fromKeys({ "foo": 1, "bar": 2});
+set = immutable.Set();
+set = immutable.Set(set);
+set = set.add(3);
+set.delete(1);
+set.remove(2);
+set = set.clear();
+set = set.union(map, list);
+set = set.union([1, 2, 3], [4, 5, 6]);
+set = set.merge(map1, list);
+set = set.merge([1, 2, 3], [4, 5, 6]);
+set = set.intersect(map1, list);
+set = set.intersect([1, 2, 3], [4, 5, 6]);
+set = set.subtract(map1, list);
+set = set.subtract([1, 2, 3], [4, 5, 6]);
+set = set.withMutations((mutable: immutable.Set) => mutable);
+set = set.asMutable();
+set = set.asImmutable();
+
+
+// OrderedSet tests
+bool = immutable.OrderedSet.isOrderedSet(set);
+let orderedSet1: immutable.OrderedSet = immutable.OrderedSet.of(0, 1, 2, 3);
+orderedSet1 = immutable.OrderedSet.fromKeys(toMap);
+let orderedSet2: immutable.Set = immutable.Set.fromKeys({ "foo": 1, "bar": 2});
+
+// Stack tests
+
+let stack: immutable.Stack = immutable.Stack();
+bool = immutable.Stack.isStack(stack);
+stack = immutable.Stack.of(0, 1, 2, 3, 4, 5);
+stack = immutable.Stack(list);
+value = stack.peek();
+stack = stack.clear();
+stack = stack.unshift(0, 1, 2);
+stack = stack.unshiftAll(list);
+stack = stack.unshiftAll([1, 2, 3]);
+stack = stack.shift();
+stack = stack.push(1, 2, 3);
+stack = stack.pushAll(list);
+stack = stack.pushAll([1, 2, 3]);
+stack = stack.pop();
+stack = stack.withMutations((mutable: immutable.Stack) => mutable);
+stack = stack.asMutable();
+stack = stack.asImmutable();
+
+
+// Range and Repeat function tests
+
+let funcSeqIndexed: immutable.Seq.Indexed = immutable.Range(0, 3, 1);
+funcSeqIndexed = immutable.Repeat(2, 10);
+
+
+// Seq tests
+let seq: immutable.Seq = immutable.Seq();
+bool = immutable.Seq.isSeq(seq);
+funcSeqIndexed = immutable.Seq.of(0, 1, 2, 3);
+seq = immutable.Seq(map);
+value = seq.size;
+seq = seq.cacheResult();
+
+
+// keyed
+let seqKeyed: immutable.Seq.Keyed = immutable.Seq.Keyed();
+seqKeyed = immutable.Seq.Keyed(map);
+seqKeyed = seqKeyed.toSeq();
+
+// indexed
+let seqIndexed: immutable.Seq.Indexed = immutable.Seq.Indexed();
+seqIndexed = immutable.Seq.Indexed.of(0, 1, 2, 3);
+seqIndexed = immutable.Seq.Indexed(list);
+seqIndexed = seqIndexed.toSeq();
+
+// indexed
+let seqSet: immutable.Seq.Set = immutable.Seq.Set();
+seqSet = immutable.Seq.Set.of(0, 1, 2, 3);
+seqSet = immutable.Seq.Set(list);
+seqSet = seqSet.toSeq();
diff --git a/immutable/immutable.d.ts b/immutable/immutable.d.ts
new file mode 100644
index 0000000000..5ca32ecfe4
--- /dev/null
+++ b/immutable/immutable.d.ts
@@ -0,0 +1,2546 @@
+// Type definitions for Facebook's Immutable 3.8.1
+// Project: https://github.com/facebook/immutable-js
+// Definitions by: tht13
+// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
+
+// Core of typings are from repository itself
+
+/**
+ * Copyright (c) 2014-2015, Facebook, Inc.
+ * All rights reserved.
+ *
+ * This source code is licensed under the BSD-style license found in the
+ * LICENSE file in the root directory of this source tree. An additional grant
+ * of patent rights can be found in the PATENTS file in the same directory.
+ */
+
+/**
+ * Immutable data encourages pure functions (data-in, data-out) and lends itself
+ * to much simpler application development and enabling techniques from
+ * functional programming such as lazy evaluation.
+ *
+ * While designed to bring these powerful functional concepts to JavaScript, it
+ * presents an Object-Oriented API familiar to Javascript engineers and closely
+ * mirroring that of Array, Map, and Set. It is easy and efficient to convert to
+ * and from plain Javascript types.
+
+ * Note: all examples are presented in [ES6][]. To run in all browsers, they
+ * need to be translated to ES3. For example:
+ *
+ * // ES6
+ * foo.map(x => x * x);
+ * // ES3
+ * foo.map(function (x) { return x * x; });
+ *
+ * [ES6]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/New_in_JavaScript/ECMAScript_6_support_in_Mozilla
+ */
+
+declare namespace __Immutable {
+
+ /**
+ * Deeply converts plain JS objects and arrays to Immutable Maps and Lists.
+ *
+ * If a `reviver` is optionally provided, it will be called with every
+ * collection as a Seq (beginning with the most nested collections
+ * and proceeding to the top-level collection itself), along with the key
+ * refering to each collection and the parent JS object provided as `this`.
+ * For the top level, object, the key will be `""`. This `reviver` is expected
+ * to return a new Immutable Iterable, allowing for custom conversions from
+ * deep JS objects.
+ *
+ * This example converts JSON to List and OrderedMap:
+ *
+ * Immutable.fromJS({a: {b: [10, 20, 30]}, c: 40}, function (key, value) {
+ * var isIndexed = Immutable.Iterable.isIndexed(value);
+ * return isIndexed ? value.toList() : value.toOrderedMap();
+ * });
+ *
+ * // true, "b", {b: [10, 20, 30]}
+ * // false, "a", {a: {b: [10, 20, 30]}, c: 40}
+ * // false, "", {"": {a: {b: [10, 20, 30]}, c: 40}}
+ *
+ * If `reviver` is not provided, the default behavior will convert Arrays into
+ * Lists and Objects into Maps.
+ *
+ * `reviver` acts similarly to the [same parameter in `JSON.parse`][1].
+ *
+ * `Immutable.fromJS` is conservative in its conversion. It will only convert
+ * arrays which pass `Array.isArray` to Lists, and only raw objects (no custom
+ * prototype) to Map.
+ *
+ * Keep in mind, when using JS objects to construct Immutable Maps, that
+ * JavaScript Object properties are always strings, even if written in a
+ * quote-less shorthand, while Immutable Maps accept keys of any type.
+ *
+ * ```js
+ * var obj = { 1: "one" };
+ * Object.keys(obj); // [ "1" ]
+ * obj["1"]; // "one"
+ * obj[1]; // "one"
+ *
+ * var map = Map(obj);
+ * map.get("1"); // "one"
+ * map.get(1); // undefined
+ * ```
+ *
+ * Property access for JavaScript Objects first converts the key to a string,
+ * but since Immutable Map keys can be of any type the argument to `get()` is
+ * not altered.
+ *
+ * [1]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/JSON/parse#Example.3A_Using_the_reviver_parameter
+ * "Using the reviver parameter"
+ */
+ export function fromJS(
+ json: any,
+ reviver?: (k: any, v: Iterable) => any
+ ): any;
+
+
+ /**
+ * Value equality check with semantics similar to `Object.is`, but treats
+ * Immutable `Iterable`s as values, equal if the second `Iterable` includes
+ * equivalent values.
+ *
+ * It's used throughout Immutable when checking for equality, including `Map`
+ * key equality and `Set` membership.
+ *
+ * var map1 = Immutable.Map({a:1, b:1, c:1});
+ * var map2 = Immutable.Map({a:1, b:1, c:1});
+ * assert(map1 !== map2);
+ * assert(Object.is(map1, map2) === false);
+ * assert(Immutable.is(map1, map2) === true);
+ *
+ * Note: Unlike `Object.is`, `Immutable.is` assumes `0` and `-0` are the same
+ * value, matching the behavior of ES6 Map key equality.
+ */
+ export function is(first: any, second: any): boolean;
+
+
+ /**
+ * Lists are ordered indexed dense collections, much like a JavaScript
+ * Array.
+ *
+ * Lists are immutable and fully persistent with O(log32 N) gets and sets,
+ * and O(1) push and pop.
+ *
+ * Lists implement Deque, with efficient addition and removal from both the
+ * end (`push`, `pop`) and beginning (`unshift`, `shift`).
+ *
+ * Unlike a JavaScript Array, there is no distinction between an
+ * "unset" index and an index set to `undefined`. `List#forEach` visits all
+ * indices from 0 to size, regardless of whether they were explicitly defined.
+ */
+ export module List {
+
+ /**
+ * True if the provided value is a List
+ */
+ function isList(maybeList: any): boolean;
+
+ /**
+ * Creates a new List containing `values`.
+ */
+ function of(...values: T[]): List;
+ }
+
+ /**
+ * Create a new immutable List containing the values of the provided
+ * iterable-like.
+ */
+ export function List(): List;
+ export function List(iter: Iterable.Indexed): List;
+ export function List(iter: Iterable.Set): List;
+ export function List(iter: Iterable.Keyed): List<[K,V]>;
+ export function List(array: Array): List;
+ export function List(iterator: Iterator): List;
+ export function List(iterable: Iterable): List;
+
+
+ export interface List extends Collection.Indexed {
+
+ // Persistent changes
+
+ /**
+ * Returns a new List which includes `value` at `index`. If `index` already
+ * exists in this List, it will be replaced.
+ *
+ * `index` may be a negative number, which indexes back from the end of the
+ * List. `v.set(-1, "value")` sets the last item in the List.
+ *
+ * If `index` larger than `size`, the returned List's `size` will be large
+ * enough to include the `index`.
+ */
+ set(index: number, value: T): List;
+
+ /**
+ * Returns a new List which excludes this `index` and with a size 1 less
+ * than this List. Values at indices above `index` are shifted down by 1 to
+ * fill the position.
+ *
+ * This is synonymous with `list.splice(index, 1)`.
+ *
+ * `index` may be a negative number, which indexes back from the end of the
+ * List. `v.delete(-1)` deletes the last item in the List.
+ *
+ * Note: `delete` cannot be safely used in IE8
+ * @alias remove
+ */
+ delete(index: number): List;
+ remove(index: number): List;
+
+ /**
+ * Returns a new List with `value` at `index` with a size 1 more than this
+ * List. Values at indices above `index` are shifted over by 1.
+ *
+ * This is synonymous with `list.splice(index, 0, value)
+ */
+ insert(index: number, value: T): List;
+
+ /**
+ * Returns a new List with 0 size and no values.
+ */
+ clear(): List;
+
+ /**
+ * Returns a new List with the provided `values` appended, starting at this
+ * List's `size`.
+ */
+ push(...values: T[]): List;
+
+ /**
+ * Returns a new List with a size ones less than this List, excluding
+ * the last index in this List.
+ *
+ * Note: this differs from `Array#pop` because it returns a new
+ * List rather than the removed value. Use `last()` to get the last value
+ * in this List.
+ */
+ pop(): List;
+
+ /**
+ * Returns a new List with the provided `values` prepended, shifting other
+ * values ahead to higher indices.
+ */
+ unshift(...values: T[]): List;
+
+ /**
+ * Returns a new List with a size ones less than this List, excluding
+ * the first index in this List, shifting all other values to a lower index.
+ *
+ * Note: this differs from `Array#shift` because it returns a new
+ * List rather than the removed value. Use `first()` to get the first
+ * value in this List.
+ */
+ shift(): List;
+
+ /**
+ * Returns a new List with an updated value at `index` with the return
+ * value of calling `updater` with the existing value, or `notSetValue` if
+ * `index` was not set. If called with a single argument, `updater` is
+ * called with the List itself.
+ *
+ * `index` may be a negative number, which indexes back from the end of the
+ * List. `v.update(-1)` updates the last item in the List.
+ *
+ * @see `Map#update`
+ */
+ update(updater: (value: List) => List): List;
+ update(index: number, updater: (value: T) => T): List;
+ update(index: number, notSetValue: T, updater: (value: T) => T): List;
+
+ /**
+ * @see `Map#merge`
+ */
+ merge(...iterables: Iterable.Indexed[]): List;
+ merge(...iterables: Array[]): List;
+
+ /**
+ * @see `Map#mergeWith`
+ */
+ mergeWith(
+ merger: (previous?: T, next?: T, key?: number) => T,
+ ...iterables: Iterable.Indexed[]
+ ): List;
+ mergeWith(
+ merger: (previous?: T, next?: T, key?: number) => T,
+ ...iterables: Array[]
+ ): List;
+
+ /**
+ * @see `Map#mergeDeep`
+ */
+ mergeDeep(...iterables: Iterable.Indexed[]): List;
+ mergeDeep(...iterables: Array[]): List;
+
+ /**
+ * @see `Map#mergeDeepWith`
+ */
+ mergeDeepWith(
+ merger: (previous?: T, next?: T, key?: number) => T,
+ ...iterables: Iterable.Indexed[]
+ ): List;
+ mergeDeepWith(
+ merger: (previous?: T, next?: T, key?: number) => T,
+ ...iterables: Array[]
+ ): List;
+
+ /**
+ * Returns a new List with size `size`. If `size` is less than this
+ * List's size, the new List will exclude values at the higher indices.
+ * If `size` is greater than this List's size, the new List will have
+ * undefined values for the newly available indices.
+ *
+ * When building a new List and the final size is known up front, `setSize`
+ * used in conjunction with `withMutations` may result in the more
+ * performant construction.
+ */
+ setSize(size: number): List;
+
+
+ // Deep persistent changes
+
+ /**
+ * Returns a new List having set `value` at this `keyPath`. If any keys in
+ * `keyPath` do not exist, a new immutable Map will be created at that key.
+ *
+ * Index numbers are used as keys to determine the path to follow in
+ * the List.
+ */
+ setIn(keyPath: Array, value: any): List;
+ setIn(keyPath: Iterable, value: any): List
diff --git a/gridstack/index.d.ts b/gridstack/index.d.ts
index c69770a1b6..399f25e04b 100644
--- a/gridstack/index.d.ts
+++ b/gridstack/index.d.ts
@@ -11,35 +11,35 @@ interface GridStack {
/**
* Creates new widget and returns it.
*
* Widget will be always placed even if result height is more than actual grid height. You need to use will_it_fit method before calling add_widget for additional check.
*
* @param {string} el widget to add
* @param {number} x widget position x
* @param {number} y widget position y
* @param {number} width widget dimension width
* @param {number} height widget dimension height
* @param {boolean} auto_position if true then x, y parameters will be ignored and widget will be places on the first available position
*/
- add_widget(el: string, x: number, y: number, width: number, height: number, auto_position: boolean): JQuery
+ addWidget(el: string, x: number, y: number, width: number, height: number, autoPosition: boolean): JQuery
/**
* Initializes batch updates. You will see no changes until commit method is called.
*/
- batch_update():void
+ batchUpdate():void
/**
* Gets current cell height.
*/
- cell_height():number
+ cellHeight():number
/**
* Update current cell height. This method rebuilds an internal CSS style sheet. Note: You can expect performance issues if call this method too often.
* @param {number} val the cell height
*/
- cell_height(val:number):void
+ cellHeight(val:number):void
/**
* Gets current cell width.
*/
- cell_width():number
+ cellWidth():number
/**
* Finishes batch updates. Updates DOM nodes. You must call it after batch_update.
*/
commit():void
/**
@@ -58,7 +58,7 @@ interface GridStack {
* Get the position of the cell under a pixel on screen.
* @param {MousePosition} position the position of the pixel to resolve in absolute coordinates, as an object with top and leftproperties
*/
- get_cell_from_pixel(position: MousePosition): CellPosition,
+ getCellFromPixel(position: MousePosition): CellPosition,
/*
* Checks if specified area is empty.
* @param {number} x the position x.
@@ -66,7 +66,7 @@ interface GridStack {
* @param {number} width the width of to check
* @param {number} height the height of to check
*/
- is_area_empty(x: number, y: number, width: number, height: number): void
+ isAreaEmpty(x: number, y: number, width: number, height: number): void
/*
* Locks/unlocks widget.
* @param {HTMLElement} el widget to modify.
@@ -78,13 +78,13 @@ interface GridStack {
* @param {HTMLElement} el widget to modify.
* @param {number} val A numeric value of the number of columns
*/
- min_width(el: HTMLElement, val: number): void
+ minWidth(el: HTMLElement, val: number): void
/*
* Set the minHeight for a widget.
* @param {HTMLElement} el widget to modify.
* @param {number} val A numeric value of the number of rows
*/
- min_height(el: HTMLElement, val: number): void
+ minHeight(el: HTMLElement, val: number): void
/*
* Enables/Disables moving.
* @param {HTMLElement} el widget to modify.
@@ -102,13 +102,13 @@ interface GridStack {
/**
* Removes widget from the grid.
* @param {HTMLElement} el widget to modify
* @param {boolean} detach_node if false DOM node won't be removed from the tree (Optional. Default true).
*/
- remove_widget(el: HTMLElement, detach_node?: boolean): void
+ removeWidget(el: HTMLElement, detachNode?: boolean): void
/**
* Removes all widgets from the grid.
*/
- remove_all(): void
+ removeAll(): void
/**
* Changes widget size
* @param {HTMLElement} el widget to modify
@@ -124,9 +124,9 @@ interface GridStack {
resizable(el: HTMLElement, val: boolean): void
/**
* Toggle the grid static state. Also toggle the grid-stack-static class.
* @param {boolean} static_value if true the grid become static.
*/
- set_static(static_value: boolean): void
+ setStatic(staticValue: boolean): void
/**
* Updates widget position/size.
* @param {HTMLElement} el widget to modify
@@ -142,9 +142,9 @@ interface GridStack {
* @param {number} y new position y. If value is null or undefined it will be ignored.
* @param {number} width new dimensions width. If value is null or undefined it will be ignored.
* @param {number} height new dimensions height. If value is null or undefined it will be ignored.
* @param {boolean} auto_position if true then x, y parameters will be ignored and widget will be places on the first available position
*/
- will_it_fit(x: number, y: number, width: number, height: number, auto_position:boolean):boolean
+ willItFit(x: number, y: number, width: number, height: number, autoPosition:boolean):boolean
}
@@ -181,7 +181,7 @@ interface IGridstackOptions {
/**
* if true the resizing handles are shown even if the user is not hovering over the widget (default: false)
*/
- always_show_resize_handle: boolean;
+ alwaysShowResizeHandle: boolean;
/**
* turns animation on (default: true)
*/
@@ -193,7 +193,7 @@ interface IGridstackOptions {
/**
* one cell height (default: 60)
*/
- cell_height: number;
+ cellHeight: number;
/**
* allows to override jQuery UI draggable options. (default: { handle: '.grid-stack-item-content', scroll: true, appendTo: 'body' })
*/
@@ -213,15 +213,15 @@ interface IGridstackOptions {
/**
* widget class (default: 'grid-stack-item')
*/
- item_class: string;
+ itemClass: string;
/**
* minimal width.If window width is less, grid will be shown in one - column mode (default: 768)
*/
- min_width: number;
+ minWidth: number;
/**
* class for placeholder (default: 'grid-stack-placeholder')
*/
- placeholder_class: string;
+ placeholderClass: string;
/**
* allows to override jQuery UI resizable options. (default: { autoHide: true, handles: 'se' })
*/
@@ -229,11 +229,11 @@ interface IGridstackOptions {
/**
* makes grid static (default false).If true widgets are not movable/ resizable.You don't even need jQueryUI draggable/resizable. A CSS class grid-stack-static is also added to the container.
*/
- static_grid: boolean;
+ staticGrid: boolean;
/**
* vertical gap size (default: 20)
*/
- vertical_margin: number;
+ verticalMargin: number;
/**
* amount of columns (default: 12)
*/
@@ -11,35 +11,35 @@ interface GridStack {
* Creates new widget and returns it.
*
- * Widget will be always placed even if result height is more than actual grid height. You need to use will_it_fit method before calling add_widget for additional check.
+ * Widget will be always placed even if result height is more than actual grid height. You need to use willItFit method before calling addWidget for additional check.
*
* @param {string} el widget to add
@@ -11,35 +11,35 @@ interface GridStack {
* @param {number} width widget dimension width
* @param {number} height widget dimension height
- * @param {boolean} auto_position if true then x, y parameters will be ignored and widget will be places on the first available position
+ * @param {boolean} autoPosition if true then x, y parameters will be ignored and widget will be places on the first available position
*/
@@ -11,35 +11,35 @@ interface GridStack {
/**
- * Finishes batch updates. Updates DOM nodes. You must call it after batch_update.
+ * Finishes batch updates. Updates DOM nodes. You must call it after batchUpdate.
*/
commit():void
@@ -102,13 +102,13 @@ interface GridStack {
* Removes widget from the grid.
* @param {HTMLElement} el widget to modify
- * @param {boolean} detach_node if false DOM node won't be removed from the tree (Optional. Default true).
+ * @param {boolean} detachNode if false DOM node won't be removed from the tree (Optional. Default true).
*/
@@ -124,9 +124,9 @@ interface GridStack {
/**
* Toggle the grid static state. Also toggle the grid-stack-static class.
- * @param {boolean} static_value if true the grid become static.
+ * @param {boolean} staticValue if true the grid become static.
*/
@@ -142,9 +142,9 @@ interface GridStack {
* @param {number} width new dimensions width. If value is null or undefined it will be ignored.
* @param {number} height new dimensions height. If value is null or undefined it will be ignored.
- * @param {boolean} auto_position if true then x, y parameters will be ignored and widget will be places on the first available position
+ * @param {boolean} autoPosition if true then x, y parameters will be ignored and widget will be places on the first available position
*/